Digi ConnectCore Bluetooth Low Energy Python library |pypiversion| |pythonversion|
==================================================================================

This project contains the source code of the ConnectCore Bluetooth Low Energy
Python library, an easy-to-use API developed in Python that allows your Digi
International's `ConnectCore <https://www.digi.com/products/browse/connectcore>`_
modules to interact with mobile applications using the `Digi XBee Mobile SDK
<https://www.digi.com/resources/documentation/digidocs/PDFs/90002361.pdf>`_
through Bluetooth Low Energy.

This source has been contributed by Digi International.


Installation
------------

You can install ConnectCore Bluetooth Low Energy Python library using `pip
<https://pip.pypa.io/en/stable/>`_::

    $ pip install digi-connectcore-ble


Install from Source
-------------------

You can install ConnectCore Bluetooth Low Energy Python library directly from
sources. To do so, extract the source code to your computer and execute the
following command::

    $ pip install <path_to_connectcore-ble-python_dir>


Documentation
-------------

XBee Python library has user guide and API reference documentation hosted on
Read the Docs. You can find the latest, most up to date, documentation at
`latest docs <https://digi-connectcore-ble.readthedocs.io/en/latest/>`_. To see only those
features which have been released, check out the
`stable docs <https://digi-connectcore-ble.readthedocs.io/en/stable/>`_.


How to contribute
-----------------

The contributing guidelines are in the `CONTRIBUTING.rst document
<https://github.com/digi-embedded/connectcore-ble-python/blob/master/CONTRIBUTING.rst>`_.


License
-------

Copyright 2022,2023, Digi International Inc.

The `MPL 2.0 license <https://github.com/digi-embedded/connectcore-ble-python/blob/master/LICENSE.txt>`_
covers the majority of this project with the following exceptions:

* The `ISC license <https://github.com/digi-embedded/connectcore-ble-python/blob/master/examples/LICENSE.txt>`_
  covers the contents of the examples directory.

.. |pypiversion| image:: https://badge.fury.io/py/digi-connectcore-ble.svg
    :target: https://pypi.org/project/digi-connectcore-ble/
.. |pythonversion| image:: https://img.shields.io/pypi/pyversions/digi-connectcore-ble.svg
    :alt: PyPI - Python Version
